@@ -91,7 +91,7 @@ import { getShiftedTimeRange } from 'app/core/utils/timePicker';
 import { updateLocation } from '../../../core/actions';
 import { getTimeSrv, TimeSrv } from '../../dashboard/services/TimeSrv';
 import { preProcessPanelData, runRequest } from '../../dashboard/state/runRequest';
-import { PanelModel } from 'app/features/dashboard/state';
+import { PanelModel, DashboardModel } from 'app/features/dashboard/state';
 import { getExploreDatasources } from './selectors';
 import { serializeStateToUrlParam } from '@grafana/data/src/utils/url';
 
@@ -263,7 +263,6 @@ export function loadExploreDatasourcesAndSetDatasource(
 
     if (exploreDatasources.length >= 1) {
       await dispatch(changeDatasource(exploreId, datasourceName, { importQueries: true }));
-      dispatch(runQueries(exploreId));
     } else {
       dispatch(loadDatasourceMissingAction({ exploreId }));
     }
@@ -282,7 +281,7 @@ export function initializeExplore(
   containerWidth: number,
   eventBridge: Emitter,
   ui: ExploreUIState,
-  originPanelId: number
+  originPanelId?: number | null
 ): ThunkResult<void> {
   return async (dispatch, getState) => {
     dispatch(loadExploreDatasourcesAndSetDatasource(exploreId, datasourceName));
@@ -334,7 +333,7 @@ export const loadDatasourceReady = (
 export const importQueries = (
   exploreId: ExploreId,
   queries: DataQuery[],
-  sourceDataSource: DataSourceApi | undefined,
+  sourceDataSource: DataSourceApi | undefined | null,
   targetDataSource: DataSourceApi
 ): ThunkResult<void> => {
   return async dispatch => {
@@ -377,7 +376,7 @@ export const loadDatasource = (exploreId: ExploreId, instance: DataSourceApi, or
       try {
         instance.init();
       } catch (err) {
-        console.log(err);
+        console.error(err);
       }
     }
 
@@ -440,6 +439,10 @@ export const runQueries = (exploreId: ExploreId): ThunkResult<void> => {
       return;
     }
 
+    if (!datasourceInstance) {
+      return;
+    }
+
     // Some datasource's query builders allow per-query interval limits,
     // but we're using the datasource interval limit for now
     const minInterval = datasourceInstance?.interval;
@@ -570,7 +573,7 @@ export const stateSave = (): ThunkResult<void> => {
     const replace = left && left.urlReplaced === false;
     const urlStates: { [index: string]: string } = { orgId };
     const leftUrlState: ExploreUrlState = {
-      datasource: left.datasourceInstance.name,
+      datasource: left.datasourceInstance!.name,
       queries: left.queries.map(clearQueryKeys),
       range: toRawTimeRange(left.range),
       ui: {
@@ -583,7 +586,7 @@ export const stateSave = (): ThunkResult<void> => {
     urlStates.left = serializeStateToUrlParam(leftUrlState, true);
     if (split) {
       const rightUrlState: ExploreUrlState = {
-        datasource: right.datasourceInstance.name,
+        datasource: right.datasourceInstance!.name,
         queries: right.queries.map(clearQueryKeys),
         range: toRawTimeRange(right.range),
         ui: {
@@ -630,12 +633,13 @@ export const updateTime = (config: {
     const range = getTimeRange(timeZone, rawRange);
     const absoluteRange: AbsoluteTimeRange = { from: range.from.valueOf(), to: range.to.valueOf() };
 
-    getTimeSrv().init({
-      time: range.raw,
-      refresh: false,
-      getTimezone: () => timeZone,
-      timeRangeUpdated: (): any => undefined,
-    });
+    getTimeSrv().init(
+      new DashboardModel({
+        time: range.raw,
+        refresh: false,
+        timeZone,
+      })
+    );
 
     dispatch(changeRangeAction({ exploreId, range, absoluteRange }));
   };
@@ -700,9 +704,9 @@ export function splitOpen<T extends DataQuery = any>(options?: { datasourceUid:
 
     if (options) {
       rightState.queries = [];
-      rightState.graphResult = undefined;
-      rightState.logsResult = undefined;
-      rightState.tableResult = undefined;
+      rightState.graphResult = null;
+      rightState.logsResult = null;
+      rightState.tableResult = null;
       rightState.queryKeys = [];
       urlState.queries = [];
       rightState.urlState = urlState;
@@ -717,7 +721,7 @@ export function splitOpen<T extends DataQuery = any>(options?: { datasourceUid:
       ];
 
       const dataSourceSettings = getDatasourceSrv().getDataSourceSettingsByUid(options.datasourceUid);
-      await dispatch(changeDatasource(ExploreId.right, dataSourceSettings.name));
+      await dispatch(changeDatasource(ExploreId.right, dataSourceSettings!.name));
       await dispatch(setQueriesAction({ exploreId: ExploreId.right, queries }));
       await dispatch(runQueries(ExploreId.right));
     } else {
@@ -811,12 +815,19 @@ export function refreshExplore(exploreId: ExploreId): ThunkResult<void> {
     }
 
     const { urlState, update, containerWidth, eventBridge } = itemState;
+
+    if (!urlState) {
+      return;
+    }
+
     const { datasource, queries, range: urlRange, ui, originPanelId } = urlState;
     const refreshQueries: DataQuery[] = [];
+
     for (let index = 0; index < queries.length; index++) {
       const query = queries[index];
       refreshQueries.push(generateNewKeyAndAddRefIdIfMissing(query, refreshQueries, index));
     }
+
     const timeZone = getTimeZone(getState().user);
     const range = getTimeRangeFromUrl(urlRange, timeZone);
 
@@ -853,7 +864,7 @@ export function refreshExplore(exploreId: ExploreId): ThunkResult<void> {
 export interface NavigateToExploreDependencies {
   getDataSourceSrv: () => DataSourceSrv;
   getTimeSrv: () => TimeSrv;
-  getExploreUrl: (args: GetExploreUrlArguments) => Promise<string>;
+  getExploreUrl: (args: GetExploreUrlArguments) => Promise<string | undefined>;
   openInNewWindow?: (url: string) => void;
 }
 
@@ -873,7 +884,7 @@ export const navigateToExplore = (
       timeSrv: getTimeSrv(),
     });
 
-    if (openInNewWindow) {
+    if (openInNewWindow && path) {
       openInNewWindow(path);
       return;
     }
