@@ -19,7 +19,8 @@ export class ElasticResponse {
   }
 
   processMetrics(esAgg: any, target: any, seriesList: any, props: any) {
-    let metric, y, i, newSeries, bucket, value;
+    let metric, y, i, bucket, value;
+    let newSeries: any;
 
     for (y = 0; y < target.metrics.length; y++) {
       metric = target.metrics[y];
@@ -181,6 +182,10 @@ export class ElasticResponse {
             // if more of the same metric type include field field name in property
             if (otherMetrics.length > 1) {
               metricName += ' ' + metric.field;
+              if (metric.type === 'bucket_script') {
+                //Use the formula in the column name
+                metricName = metric.settings.script;
+              }
             }
 
             addMetricValue(values, metricName, bucket[metric.id].value);
@@ -524,7 +529,7 @@ const flattenHits = (hits: Doc[]): { docs: Array<Record<string, any>>; propNames
   let propNames: string[] = [];
 
   for (const hit of hits) {
-    const flattened = hit._source ? flatten(hit._source, null) : {};
+    const flattened = hit._source ? flatten(hit._source) : {};
     const doc = {
       _id: hit._id,
       _type: hit._type,
